pub trait ToHex {
// Required method
fn to_hex<T: FromIterator<char>>(&self) -> T;
}Expand description
A trait for converting a value to hexadecimal encoding
Required Methods
Sourcefn to_hex<T: FromIterator<char>>(&self) -> T
fn to_hex<T: FromIterator<char>>(&self) -> T
Converts the value of self to a hex value, constructed from
an iterator of characters.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".